<?php

/*======================================================================*\
|| #################################################################### ||
|| # GECKO 2.1                                                        # ||
|| # ---------------------------------------------------------------- # ||
|| # Copyright 2013 Gecko All Rights Reserved.                        # ||
|| # This file may not be redistributed in whole or significant part. # ||
|| #   ---------------- Gecko IS NOT FREE SOFTWARE ----------------   # ||
|| # http://www.cmsgecko.com | http://www.cmsgecko.com/license        # ||
|| #################################################################### ||
\*======================================================================*/

// Error reporting:
error_reporting(E_ALL^E_NOTICE);

// The DB connections data
require_once 'include/db.php';

// Do not go any further if install folder still exists
if (is_dir('install')) die('Please delete or rename install folder.');

if (!JAK_CACHE_DIRECTORY) die('Please define a cache directory in the db.php.');
if (!JAK_FILES_DIRECTORY) die('Please define a files directory in the db.php.');
if (!JAK_USER_DIRECTORY) die('Please define a user directory in the db.php.');

// Start the session
session_start();

// Absolute Path
define('APP_PATH', dirname(__file__) . DIRECTORY_SEPARATOR);

if (isset($_SERVER['SCRIPT_NAME'])) {

    # on Windows _APP_MAIN_DIR becomes \ and abs url would look something like HTTP_HOST\/restOfUrl, so \ should be trimed too
    $app_main_dir = rtrim(dirname($_SERVER['SCRIPT_NAME']), '/\\');
    define('_APP_MAIN_DIR', $app_main_dir);
} else {
    die('[config.php] Cannot determine APP_MAIN_DIR, please set manual and comment this line');
}

// Get the jak DB class
if (JAK_MYSQL_CONNECTION == 1) {
	require_once 'class/class.db.php';
} else {
	require_once 'class/class.dbn.php';
}

// MySQLi connection
$jakdb = new jak_mysql(DB_HOST, DB_USER, DB_PASS, DB_NAME, DB_PORT);
$jakdb->set_charset("utf8");

// All important files
include_once 'include/functions.php';
include_once 'class/class.jakbase.php';
include_once 'class/class.postmail.php';
include_once 'class/class.userlogin.php';
include_once 'class/class.user.php';
include_once 'class/class.usergroup.php';
include_once 'class/class.plugins.php';
include_once 'class/class.hooks.php';
include_once 'class/class.paginator.php';
include_once 'class/class.tags.php';

// Undo register_globals.
undoRegisterGlobals();

// If magic quotes is on, strip the slashes that it added.
if (get_magic_quotes_gpc()) {
	$_REQUEST = array_map("undoMagicQuotes", $_REQUEST);
	$_GET = array_map("undoMagicQuotes", $_GET);
	$_POST = array_map("undoMagicQuotes", $_POST);
	$_COOKIE = array_map("undoMagicQuotes", $_COOKIE);
}

// Now launch the rewrite class, depending on the settings in db.
$getURL = New JAK_rewrite($_SERVER['REQUEST_URI']);

// We are not using apache so take the ugly urls
$tempp = $getURL->jakGetseg(0);
$tempp1 = $getURL->jakGetseg(1);
$tempp2 = $getURL->jakGetseg(2);
$tempp3 = $getURL->jakGetseg(3);
$tempp4 = $getURL->jakGetseg(4);
$tempp5 = $getURL->jakGetseg(5);
$tempp6 = $getURL->jakGetseg(6);

// Check if we want caching
if (!is_dir(APP_PATH.JAK_CACHE_DIRECTORY)) mkdir(APP_PATH.JAK_CACHE_DIRECTORY, 0755);

// define file better for caching
$cachedefinefile = APP_PATH.JAK_CACHE_DIRECTORY.'/define.php';

if (!file_exists($cachedefinefile)) {

$allsettings = "<?php\n";

// Get the general settings out the database
$result = $jakdb->query('SELECT varname, value FROM '.DB_PREFIX.'setting');
    while ($row = $result->fetch_assoc()) {
    	// collect each record into a define
    	
    	// Now check if sting contains html and do something about it!
    	if (strlen($row['value']) != strlen(filter_var($row['value'], FILTER_SANITIZE_STRING))) {
    		$defvar  = 'htmlspecialchars_decode("'.htmlspecialchars($row['value']).'")';
    	} else {
    		$defvar = "'".$row["value"]."'";
    	}
    	
        $allsettings .= "define('JAK_".strtoupper($row['varname'])."', ".$defvar.");\n";
    }
    
$allsettings .= "?>";
        
JAK_base::jakWriteinCache($cachedefinefile, $allsettings, '');

}

// Now include the created definefile
include_once $cachedefinefile;

// timezone from server
date_default_timezone_set(JAK_TIMEZONESERVER);
$jakdb->query('SET time_zone = "'.date("P").'"');

// Set the last activity and session into cookies
setcookie('lastactivity', time(), time() + 60 * 60 * 24 * 10, JAK_COOKIE_PATH);
setcookie('usrsession', session_id(), time() + 60 * 60 * 24 * 10, JAK_COOKIE_PATH);

// Check if user is logged in
$jakuserlogin = new JAK_userlogin();
$jakuserrow = $jakuserlogin->jakCheckLogged();
$jakuser = new JAK_user($jakuserrow);
if ($jakuser) {
	define(JAK_USERID_CMS, $jakuser->getVar("id"));
} else {
	define(JAK_USERID_CMS, false);
}

if (JAK_USERID_CMS) {
	// Get the usergroupid out from this user
	$usergroupid = $jakuser->getVar("usergroupid");
	
	// Update last activity from this user
	$jakuserlogin->jakUpdatelastactivity(JAK_USERID_CMS);

} else {

	// Standard usergroup id for guests
	$usergroupid = 1;

}

// define file better for caching
$cachegroupfile = APP_PATH.JAK_CACHE_DIRECTORY.'/usergroup'.$usergroupid.'.php';

if (!file_exists($cachegroupfile)) {

// Let's call the usergroup class
$resultusrg = $jakdb->query('SELECT * FROM '.DB_PREFIX.'usergroup WHERE id = "'.$usergroupid.'" LIMIT 1');
$rowusrg = $resultusrg->fetch_assoc();

$groupf = "<?php\n\$groupserialize = '".base64_encode(gzcompress(serialize($rowusrg)))."';\n\n\$rowusrg = unserialize(gzuncompress(base64_decode(\$groupserialize)));\n?>";

JAK_base::jakWriteinCache($cachegroupfile, $groupf, '');

}

// Now include the created definefile
include_once $cachegroupfile;

// Get the usergroup class
$jakusergroup = new JAK_usergroup($rowusrg);

// Check if https is activated
if (JAK_SITEHTTPS) {
	define('BASE_URL', 'https://' . FULL_SITE_DOMAIN . _APP_MAIN_DIR . '/');
} else {
	define('BASE_URL', 'http://' . FULL_SITE_DOMAIN . _APP_MAIN_DIR . '/');
}

// Now let's go for the multi language feature
if ($jakuser->jakLangaccess(JAK_USERID_CMS) && (JAK_LANG2 || JAK_LANG3)) {
	require_once ("include/langcontrol.php");
	define('JAK_MULTILANGA', true);
} else {
	$_SESSION['jak_language_sc'] = '';
	define('JAK_MULTILANGA', false);
	define('JAK_LANGCONTROL', JAK_LANG);
	define('BASE_URL_LOGO', BASE_URL);
}

// Define for template the real request
$realrequest = substr($getURL->jakRealrequest(), 1);
define('JAK_PARSE_REQUEST', $realrequest);
?>